#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.4.1
visibility:           public
id:                   text-builder-dev-0.3.4.1-1zVvTaEfnvG1IJbKHhOJQV
key:                  text-builder-dev-0.3.4.1-1zVvTaEfnvG1IJbKHhOJQV
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text, Builders
abi:                  5f4bc85cd2cd2af23b891fc7afa0aef6
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Prelude
    TextBuilderDev.Unicode TextBuilderDev.Utf16View
    TextBuilderDev.Utf8View

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.4.1-1zVvTaEfnvG1IJbKHhOJQV
depends:
    QuickCheck-2.15.0.1-FUcewYgFPTwGfyjnEpPlTz base-4.18.2.1
    bytestring-0.11.5.3 deferred-folds-0.9.18.9-1JaV7JCa2RX8J8KWdabppg
    isomorphism-class-0.1.1-7EFpBvfGenT1v83dolZsMe
    quickcheck-instances-0.3.33-4w3csCL9xx3A20YUmBmdgD
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

